@@ -38,14 +38,13 @@ void ImportImapSettingProgressPageTest::shouldHaveDefaultValue()
 {
     ImportImapSettingProgressPage w;
 
-    QTextEdit *mProgressTextEdit = w.findChild<QTextEdit *>(QStringLiteral("textedit"));
+    auto *mProgressTextEdit = w.findChild<QTextEdit *>(QStringLiteral("textedit"));
     QVERIFY(mProgressTextEdit);
     QVERIFY(mProgressTextEdit->isReadOnly());
     QVERIFY(mProgressTextEdit->document()->isEmpty());
 
-    QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
+    auto *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 }
 
 QTEST_MAIN(ImportImapSettingProgressPageTest)
