@@ -51,7 +51,7 @@ SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
 
     //Server page
     QWidget *serverConfigureWiget = new QWidget;
-    QVBoxLayout *layout = new QVBoxLayout(serverConfigureWiget);
+    auto *layout = new QVBoxLayout(serverConfigureWiget);
     mServerWidget = new SieveEditorConfigureServerWidget;
     layout->addWidget(mServerWidget);
 
@@ -83,8 +83,8 @@ SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
 
     mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
 
-    QHBoxLayout *userFeedBackLayout = new QHBoxLayout(userFeedBackWidget);
-    userFeedBackLayout->setContentsMargins(0, 0, 0, 0);
+    auto *userFeedBackLayout = new QHBoxLayout(userFeedBackWidget);
+    userFeedBackLayout->setContentsMargins({});
     userFeedBackLayout->addWidget(mUserFeedbackWidget);
 
     mUserFeedbackWidget->setFeedbackProvider(UserFeedBackManager::self()->userFeedbackProvider());
